GradientStatus

Struct GradientStatus 

pub struct GradientStatus {
    pub message: StatusMessage,
    pub x: DVector<Float>,
    pub fx: Float,
    pub n_f_evals: usize,
    pub n_g_evals: usize,
    pub n_h_evals: usize,
    pub hess: Option<DMatrix<Float>>,
    pub cov: Option<DMatrix<Float>>,
    pub err: Option<DVector<Float>>,
}
A status message struct containing all information about a minimization result.

Fields

message: StatusMessage

A StatusMessage that can be set by Algorithms.

x: DVector<Float>

The current parameters of the minimization.

fx: Float

The current value of the minimization problem function at GradientStatus::x.

n_f_evals: usize

The number of function evaluations (approximately, this is left up to individual Algorithms to correctly compute and may not be exact).

n_g_evals: usize

The number of gradient evaluations (approximately, this is left up to individual Algorithms to correctly compute and may not be exact).

n_h_evals: usize

The number of Hessian evaluations (approximately, this is left up to individual Algorithms to correctly compute and may not be exact).

hess: Option<DMatrix<Float>>

The Hessian matrix at the end of the fit (None if not computed yet)

cov: Option<DMatrix<Float>>

Covariance matrix at the end of the fit (None if not computed yet)

err: Option<DVector<Float>>

Errors on parameters at the end of the fit (None if not computed yet)

Implementations

Source

impl GradientStatus

pub fn initialize(&mut self, pos: (DVector<Float>, Float))

Updates the GradientStatus::x and GradientStatus::fx fields and sets the status message to an initialized state.

pub fn set_position(&mut self, pos: (DVector<Float>, Float))

Updates the GradientStatus::x and GradientStatus::fx fields and sets the status message to a step state.

pub fn initialize_silent(&mut self, pos: (DVector<Float>, Float))

Updates the GradientStatus::x and GradientStatus::fx fields and marks the status as initialized without formatting a message payload.

pub fn set_position_silent(&mut self, pos: (DVector<Float>, Float))

Updates the GradientStatus::x and GradientStatus::fx fields and marks the status as a step without formatting a message payload.

pub fn inc_n_f_evals(&mut self)

Increments GradientStatus::n_f_evals by 1.

pub fn inc_n_g_evals(&mut self)

Increments GradientStatus::n_g_evals by 1.

pub fn inc_n_h_evals(&mut self)

Increments GradientStatus::n_h_evals by 1.

pub fn set_cov(&mut self, covariance: Option<DMatrix<Float>>)

Updates the GradientStatus::err field.

pub fn set_hess(&mut self, hessian: &DMatrix<Float>)

Updates the GradientStatus::hess field and computes GradientStatus::cov and GradientStatus::err.