Callbacks

Struct Callbacks 

pub struct Callbacks<A, P, S, U, E, C>(/* private fields */);
A set of Terminators and/or Observers which can be used as an input to Algorithm::process.

Implementations

Source

impl<A, P, S, U, E, C> Callbacks<A, P, S, U, E, C>
where A: Algorithm<P, S, U, E, Config = C>, S: Status,

pub const fn empty() -> Self

Create an empty set of callbacks.

pub fn with_terminator<T>(self, terminator: T) -> Self
where T: Terminator<A, P, S, U, E, C> + 'static,

Return the set of Callbacks with an additional Terminator added.

pub fn with_observer<O>(self, observer: O) -> Self
where O: Observer<A, P, S, U, E, C> + 'static,

Return the set of Callbacks with an additional Observer added.

pub fn check_for_termination( &mut self, current_step: usize, algorithm: &mut A, problem: &P, status: &mut S, args: &U, config: &C, ) -> ControlFlow<()>

Runs all of the contained Terminators and Observers and returns ControlFlow::Break if any of the terminators return ControlFlow::Break.