pub struct DebugObserver;Expand description
A debugging callback which prints out the step, status, and any user data at the current step in an algorithm.
Usage:
use ganesh::traits::*;
use ganesh::algorithms::gradient_free::{NelderMead, NelderMeadConfig};
use ganesh::test_functions::Rosenbrock;
use ganesh::core::DebugObserver;
let problem = Rosenbrock { n: 2 };
let mut nm: NelderMead = Default::default();
let config = NelderMeadConfig::default();
let result = nm
.process(
&problem,
&(),
[2.3, 3.4],
config,
NelderMead::default_callbacks().with_observer(DebugObserver),
)
.unwrap();
// ^ This will print debug messages for each step
assert!(result.message.success());Trait Implementations
Sourceimpl Clone for DebugObserver
impl Clone for DebugObserver
Sourcefn clone(&self) -> DebugObserver
fn clone(&self) -> DebugObserver
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DebugObserver
Sourceimpl<A, P, S, U, E, C> Observer<A, P, S, U, E, C> for DebugObserver
impl<A, P, S, U, E, C> Observer<A, P, S, U, E, C> for DebugObserver