pub enum GaneshError {
ConfigError(String),
NumericalError(String),
}Expand description
A general error type for the ganesh crate
Variants
ConfigError(String)
Variant for errors which may occur while configuring an Algorithm
NumericalError(String)
Variant for numerical failures such as singular solves or invalid covariance factorizations