StatusMessage

Struct StatusMessage 

pub struct StatusMessage {
    pub status_type: StatusType,
    pub text: Option<Cow<'static, str>>,
}
A status message for an Algorithm

Fields

status_type: StatusType

The status type

text: Option<Cow<'static, str>>

The internal custom message

Implementations

Source

impl StatusMessage

pub fn reset(&mut self)

Reset the status message to uninitialized

pub fn uninitialize(&mut self)

Set the status message to uninitialized

pub fn initialize(&mut self)

Set the status message to initialized

pub fn set_initialized(self) -> Self

Set the status message to initialized

pub fn initialize_with_message(&mut self, message: impl Into<Cow<'static, str>>)

Set the status message to initialized with a custom message

pub fn set_initialized_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self

Set the status message to initialized with a custom message

pub fn step(&mut self)

Set the status message to a step

pub fn set_step(self) -> Self

Set the status message to a step

pub fn step_with_message(&mut self, message: impl Into<Cow<'static, str>>)

Set the status message to a step with a custom message

pub fn set_step_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self

Set the status message to a step with a custom message

pub fn succeed(&mut self)

Set the status message to success

pub fn set_success(self) -> Self

Set the status message to success

pub fn succeed_with_message(&mut self, message: impl Into<Cow<'static, str>>)

Set the status message to converged with a custom message

pub fn set_success_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self

Set the status message to converged with a custom message

pub fn fail(&mut self)

Set the status message to failed

pub fn set_failed(self) -> Self

Set the status message to failed

pub fn fail_with_message(&mut self, message: impl Into<Cow<'static, str>>)

Set the status message to failed with a custom message

pub fn set_failed_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self

Set the status message to failed with a custom message

pub fn custom(&mut self, message: impl Into<Cow<'static, str>>)

Set the status message to a custom message

pub fn custom_with_message(&mut self, message: impl Into<Cow<'static, str>>)

Set the status message to a custom message.

pub fn set_custom(self, message: impl Into<Cow<'static, str>>) -> Self

Set the status message to a custom message

pub fn text(&self) -> Option<&str>

Returns the message text payload, if one exists.

pub fn text_or_empty(&self) -> &str

Returns the message text payload, or an empty string for message-less status transitions.

pub const fn success(&self) -> bool

Returns true if the status message is StatusType::Success