pub struct Callbacks<A, P, S, U, E, C>(/* private fields */);Expand description
A set of Terminators and/or Observers which can be used as an input to Algorithm::process.
Implementations
Sourceimpl<A, P, S, U, E, C> Callbacks<A, P, S, U, E, C>
impl<A, P, S, U, E, C> Callbacks<A, P, S, U, E, C>
Sourcepub fn with_terminator<T>(self, terminator: T) -> Selfwhere
T: Terminator<A, P, S, U, E, C> + 'static,
pub fn with_terminator<T>(self, terminator: T) -> Selfwhere
T: Terminator<A, P, S, U, E, C> + 'static,
Return the set of Callbacks with an additional Terminator added.
Sourcepub fn with_observer<O>(self, observer: O) -> Selfwhere
O: Observer<A, P, S, U, E, C> + 'static,
pub fn with_observer<O>(self, observer: O) -> Selfwhere
O: Observer<A, P, S, U, E, C> + 'static,
Sourcepub fn check_for_termination(
&mut self,
current_step: usize,
algorithm: &mut A,
problem: &P,
status: &mut S,
args: &U,
config: &C,
) -> ControlFlow<()>
pub fn check_for_termination( &mut self, current_step: usize, algorithm: &mut A, problem: &P, status: &mut S, args: &U, config: &C, ) -> ControlFlow<()>
Runs all of the contained Terminators and Observers and returns ControlFlow::Break if any of the terminators return ControlFlow::Break.