pub struct StatusMessage {
pub status_type: StatusType,
pub text: Option<Cow<'static, str>>,
}Expand description
A status message for an Algorithm
Fields
status_type: StatusTypeThe status type
text: Option<Cow<'static, str>>The internal custom message
Implementations
Sourceimpl StatusMessage
impl StatusMessage
Sourcepub fn uninitialize(&mut self)
pub fn uninitialize(&mut self)
Set the status message to uninitialized
Sourcepub fn initialize(&mut self)
pub fn initialize(&mut self)
Set the status message to initialized
Sourcepub fn set_initialized(self) -> Self
pub fn set_initialized(self) -> Self
Set the status message to initialized
Sourcepub fn initialize_with_message(&mut self, message: impl Into<Cow<'static, str>>)
pub fn initialize_with_message(&mut self, message: impl Into<Cow<'static, str>>)
Set the status message to initialized with a custom message
Sourcepub fn set_initialized_with_message(
self,
message: impl Into<Cow<'static, str>>,
) -> Self
pub fn set_initialized_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self
Set the status message to initialized with a custom message
Sourcepub fn step_with_message(&mut self, message: impl Into<Cow<'static, str>>)
pub fn step_with_message(&mut self, message: impl Into<Cow<'static, str>>)
Set the status message to a step with a custom message
Sourcepub fn set_step_with_message(
self,
message: impl Into<Cow<'static, str>>,
) -> Self
pub fn set_step_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self
Set the status message to a step with a custom message
Sourcepub fn set_success(self) -> Self
pub fn set_success(self) -> Self
Set the status message to success
Sourcepub fn succeed_with_message(&mut self, message: impl Into<Cow<'static, str>>)
pub fn succeed_with_message(&mut self, message: impl Into<Cow<'static, str>>)
Set the status message to converged with a custom message
Sourcepub fn set_success_with_message(
self,
message: impl Into<Cow<'static, str>>,
) -> Self
pub fn set_success_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self
Set the status message to converged with a custom message
Sourcepub fn set_failed(self) -> Self
pub fn set_failed(self) -> Self
Set the status message to failed
Sourcepub fn fail_with_message(&mut self, message: impl Into<Cow<'static, str>>)
pub fn fail_with_message(&mut self, message: impl Into<Cow<'static, str>>)
Set the status message to failed with a custom message
Sourcepub fn set_failed_with_message(
self,
message: impl Into<Cow<'static, str>>,
) -> Self
pub fn set_failed_with_message( self, message: impl Into<Cow<'static, str>>, ) -> Self
Set the status message to failed with a custom message
Sourcepub fn custom(&mut self, message: impl Into<Cow<'static, str>>)
pub fn custom(&mut self, message: impl Into<Cow<'static, str>>)
Set the status message to a custom message
Sourcepub fn custom_with_message(&mut self, message: impl Into<Cow<'static, str>>)
pub fn custom_with_message(&mut self, message: impl Into<Cow<'static, str>>)
Set the status message to a custom message.
Sourcepub fn set_custom(self, message: impl Into<Cow<'static, str>>) -> Self
pub fn set_custom(self, message: impl Into<Cow<'static, str>>) -> Self
Set the status message to a custom message
Sourcepub fn text_or_empty(&self) -> &str
pub fn text_or_empty(&self) -> &str
Returns the message text payload, or an empty string for message-less status transitions.
Sourcepub const fn success(&self) -> bool
pub const fn success(&self) -> bool
Returns true if the status message is StatusType::Success